@@ -56,6 +56,10 @@ class Port(resource.Resource):
     #: In GET operations, the binding:vnic_type extended attribute is
     #: visible to only port owners and administrative users.
     binding_vnic_type = resource.prop('binding:vnic_type')
+    #: Timestamp when the port was created.
+    created_at = resource.prop('created_at')
+    #: The port description.
+    description = resource.prop('description')
     #: Device ID of this port.
     device_id = resource.prop('device_id')
     #: Device owner of this port (e.g. ``network:dhcp``).
@@ -90,3 +94,5 @@ class Port(resource.Resource):
     security_group_ids = resource.prop('security_groups', type=list)
     #: The port status. Value is ``ACTIVE`` or ``DOWN``.
     status = resource.prop('status')
+    #: Timestamp when the port was last updated.
+    updated_at = resource.prop('updated_at')
